/*
   Copyright (C) 2002   Alexandre Courbot
   Copyright (C) 2002   Dmitri Katchalov

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY.

   See the COPYING file for more details.
*/


/* Bitmasks used for the port control register */ 
typedef enum
{ hostclk = 1, hostack = 2, nreverserequest = 4, active1284 = 8,
  irqen = 0x10, reverse = 0x20 } CONTROL_BITS;

/* Bitmasks used for the port status register */ 
typedef enum
{ irqflag = 4, periprequest = 8, xflag = 0x10, nackreverse = 0x20,
  periphclk = 0x40, periphack = 0x80 } STATUS_BITS;

/* Error codes */ 
typedef enum
{ failure = 0, success = 1, timeout, checksum_error, bad_version } rome_error; 


/* List of files contained into the rome */ 
typedef struct
{
    struct 
    {
        char * filename;
        unsigned int size;
        char date[30];
        char rawpacket[152]; 
    }file[20];

    unsigned int nbr_files; 
}rome_filelist; 

/* Informations about the rome */ 
typedef struct
{
    unsigned int mem_tot;
    unsigned int mem_avail;
    unsigned int nbr_files; 
}rome_info; 


rome_error rome_filelist_init (rome_filelist * flist); 
rome_error rome_filelist_cleanup (rome_filelist * flist); 
rome_error rome_filelist_add (rome_filelist * flist, char * filename, int size,
                              char * date, char * rpacket); 
 
rome_error rome_init ();
rome_error rome_cleanup (); 
rome_error rome_set_forward (); 
rome_error rome_set_reverse (); 
rome_error rome_wait_for (unsigned char bit, unsigned char value); 
rome_error rome_write_buf (char * buf, int size); 
int rome_read_buf (int count); 
rome_error rome_read_packet (); 

rome_error rome_get_info (rome_info * ifo); 
rome_error rome_get_serial_number (); 
rome_error rome_list_next_file (char * last); 
rome_error rome_list_files (rome_filelist * flist); 
rome_error rome_get_file (FILE * file, rome_filelist * flist, unsigned int nbr); 
rome_error rome_put_file (FILE * file, char * fname); 
rome_error rome_remove_file (rome_filelist * flist, unsigned int nbr); 

